# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetKeyPrefixResult',
    'AwaitableGetKeyPrefixResult',
    'get_key_prefix',
    'get_key_prefix_output',
]

@pulumi.output_type
class GetKeyPrefixResult:
    """
    A collection of values returned by getKeyPrefix.
    """
    def __init__(__self__, datacenter=None, id=None, namespace=None, partition=None, path_prefix=None, subkey_collection=None, subkeys=None, token=None, var=None):
        if datacenter and not isinstance(datacenter, str):
            raise TypeError("Expected argument 'datacenter' to be a str")
        pulumi.set(__self__, "datacenter", datacenter)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if namespace and not isinstance(namespace, str):
            raise TypeError("Expected argument 'namespace' to be a str")
        pulumi.set(__self__, "namespace", namespace)
        if partition and not isinstance(partition, str):
            raise TypeError("Expected argument 'partition' to be a str")
        pulumi.set(__self__, "partition", partition)
        if path_prefix and not isinstance(path_prefix, str):
            raise TypeError("Expected argument 'path_prefix' to be a str")
        pulumi.set(__self__, "path_prefix", path_prefix)
        if subkey_collection and not isinstance(subkey_collection, list):
            raise TypeError("Expected argument 'subkey_collection' to be a list")
        pulumi.set(__self__, "subkey_collection", subkey_collection)
        if subkeys and not isinstance(subkeys, dict):
            raise TypeError("Expected argument 'subkeys' to be a dict")
        pulumi.set(__self__, "subkeys", subkeys)
        if token and not isinstance(token, str):
            raise TypeError("Expected argument 'token' to be a str")
        pulumi.set(__self__, "token", token)
        if var and not isinstance(var, dict):
            raise TypeError("Expected argument 'var' to be a dict")
        pulumi.set(__self__, "var", var)

    @property
    @pulumi.getter
    def datacenter(self) -> str:
        """
        The datacenter the keys are being read from.
        """
        return pulumi.get(self, "datacenter")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def namespace(self) -> Optional[str]:
        return pulumi.get(self, "namespace")

    @property
    @pulumi.getter
    def partition(self) -> Optional[str]:
        return pulumi.get(self, "partition")

    @property
    @pulumi.getter(name="pathPrefix")
    def path_prefix(self) -> str:
        """
        the common prefix shared by all keys being read.
        * `var.<name>` - For each name given, the corresponding attribute
        has the value of the key.
        """
        return pulumi.get(self, "path_prefix")

    @property
    @pulumi.getter(name="subkeyCollection")
    def subkey_collection(self) -> Optional[Sequence['outputs.GetKeyPrefixSubkeyCollectionResult']]:
        return pulumi.get(self, "subkey_collection")

    @property
    @pulumi.getter
    def subkeys(self) -> Mapping[str, str]:
        """
        A map of the subkeys and values is set if no `subkey`
        block is provided.
        """
        return pulumi.get(self, "subkeys")

    @property
    @pulumi.getter
    @_utilities.deprecated("""The token argument has been deprecated and will be removed in a future release.
Please use the token argument in the provider configuration""")
    def token(self) -> Optional[str]:
        return pulumi.get(self, "token")

    @property
    @pulumi.getter
    def var(self) -> Mapping[str, str]:
        return pulumi.get(self, "var")


class AwaitableGetKeyPrefixResult(GetKeyPrefixResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetKeyPrefixResult(
            datacenter=self.datacenter,
            id=self.id,
            namespace=self.namespace,
            partition=self.partition,
            path_prefix=self.path_prefix,
            subkey_collection=self.subkey_collection,
            subkeys=self.subkeys,
            token=self.token,
            var=self.var)


def get_key_prefix(datacenter: Optional[str] = None,
                   namespace: Optional[str] = None,
                   partition: Optional[str] = None,
                   path_prefix: Optional[str] = None,
                   subkey_collection: Optional[Sequence[Union['GetKeyPrefixSubkeyCollectionArgs', 'GetKeyPrefixSubkeyCollectionArgsDict']]] = None,
                   token: Optional[str] = None,
                   opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetKeyPrefixResult:
    """
    ## Example Usage

    ```python
    import pulumi
    import pulumi_aws as aws
    import pulumi_consul as consul

    app = consul.get_key_prefix(datacenter="nyc1",
        token="abcd",
        path_prefix="myapp/config/",
        subkey_collection=[{
            "name": "ami",
            "path": "app/launch_ami",
            "default": "ami-1234",
        }])
    # Start our instance with the dynamic ami value
    app_instance = aws.index.Instance("app", ami=app.var.ami)
    ```

    ```python
    import pulumi
    import pulumi_aws as aws
    import pulumi_consul as consul

    web = consul.get_key_prefix(datacenter="nyc1",
        token="efgh",
        path_prefix="myapp/config/")
    # Start our instance with the dynamic ami value
    web_instance = aws.index.Instance("web", ami=web.subkeys.app_launch_ami)
    ```


    :param str datacenter: The datacenter to use. This overrides the
           agent's default datacenter and the datacenter in the provider setup.
    :param str namespace: The namespace to lookup the keys within.
    :param str partition: The namespace to lookup the keys within.
    :param str path_prefix: Specifies the common prefix shared by all keys
           that will be read by this data source instance. In most cases, this will
           end with a slash to read a "folder" of subkeys.
    :param Sequence[Union['GetKeyPrefixSubkeyCollectionArgs', 'GetKeyPrefixSubkeyCollectionArgsDict']] subkey_collection: Specifies a subkey in Consul to be read. Supported
           values documented below. Multiple blocks supported.
    :param str token: The ACL token to use. This overrides the
           token that the agent provides by default.
    """
    __args__ = dict()
    __args__['datacenter'] = datacenter
    __args__['namespace'] = namespace
    __args__['partition'] = partition
    __args__['pathPrefix'] = path_prefix
    __args__['subkeyCollection'] = subkey_collection
    __args__['token'] = token
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('consul:index/getKeyPrefix:getKeyPrefix', __args__, opts=opts, typ=GetKeyPrefixResult).value

    return AwaitableGetKeyPrefixResult(
        datacenter=pulumi.get(__ret__, 'datacenter'),
        id=pulumi.get(__ret__, 'id'),
        namespace=pulumi.get(__ret__, 'namespace'),
        partition=pulumi.get(__ret__, 'partition'),
        path_prefix=pulumi.get(__ret__, 'path_prefix'),
        subkey_collection=pulumi.get(__ret__, 'subkey_collection'),
        subkeys=pulumi.get(__ret__, 'subkeys'),
        token=pulumi.get(__ret__, 'token'),
        var=pulumi.get(__ret__, 'var'))
def get_key_prefix_output(datacenter: Optional[pulumi.Input[Optional[str]]] = None,
                          namespace: Optional[pulumi.Input[Optional[str]]] = None,
                          partition: Optional[pulumi.Input[Optional[str]]] = None,
                          path_prefix: Optional[pulumi.Input[str]] = None,
                          subkey_collection: Optional[pulumi.Input[Optional[Sequence[Union['GetKeyPrefixSubkeyCollectionArgs', 'GetKeyPrefixSubkeyCollectionArgsDict']]]]] = None,
                          token: Optional[pulumi.Input[Optional[str]]] = None,
                          opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetKeyPrefixResult]:
    """
    ## Example Usage

    ```python
    import pulumi
    import pulumi_aws as aws
    import pulumi_consul as consul

    app = consul.get_key_prefix(datacenter="nyc1",
        token="abcd",
        path_prefix="myapp/config/",
        subkey_collection=[{
            "name": "ami",
            "path": "app/launch_ami",
            "default": "ami-1234",
        }])
    # Start our instance with the dynamic ami value
    app_instance = aws.index.Instance("app", ami=app.var.ami)
    ```

    ```python
    import pulumi
    import pulumi_aws as aws
    import pulumi_consul as consul

    web = consul.get_key_prefix(datacenter="nyc1",
        token="efgh",
        path_prefix="myapp/config/")
    # Start our instance with the dynamic ami value
    web_instance = aws.index.Instance("web", ami=web.subkeys.app_launch_ami)
    ```


    :param str datacenter: The datacenter to use. This overrides the
           agent's default datacenter and the datacenter in the provider setup.
    :param str namespace: The namespace to lookup the keys within.
    :param str partition: The namespace to lookup the keys within.
    :param str path_prefix: Specifies the common prefix shared by all keys
           that will be read by this data source instance. In most cases, this will
           end with a slash to read a "folder" of subkeys.
    :param Sequence[Union['GetKeyPrefixSubkeyCollectionArgs', 'GetKeyPrefixSubkeyCollectionArgsDict']] subkey_collection: Specifies a subkey in Consul to be read. Supported
           values documented below. Multiple blocks supported.
    :param str token: The ACL token to use. This overrides the
           token that the agent provides by default.
    """
    __args__ = dict()
    __args__['datacenter'] = datacenter
    __args__['namespace'] = namespace
    __args__['partition'] = partition
    __args__['pathPrefix'] = path_prefix
    __args__['subkeyCollection'] = subkey_collection
    __args__['token'] = token
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('consul:index/getKeyPrefix:getKeyPrefix', __args__, opts=opts, typ=GetKeyPrefixResult)
    return __ret__.apply(lambda __response__: GetKeyPrefixResult(
        datacenter=pulumi.get(__response__, 'datacenter'),
        id=pulumi.get(__response__, 'id'),
        namespace=pulumi.get(__response__, 'namespace'),
        partition=pulumi.get(__response__, 'partition'),
        path_prefix=pulumi.get(__response__, 'path_prefix'),
        subkey_collection=pulumi.get(__response__, 'subkey_collection'),
        subkeys=pulumi.get(__response__, 'subkeys'),
        token=pulumi.get(__response__, 'token'),
        var=pulumi.get(__response__, 'var')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetKeysResult',
    'AwaitableGetKeysResult',
    'get_keys',
    'get_keys_output',
]

@pulumi.output_type
class GetKeysResult:
    """
    A collection of values returned by getKeys.
    """
    def __init__(__self__, datacenter=None, error_on_missing_keys=None, id=None, keys=None, namespace=None, partition=None, token=None, var=None):
        if datacenter and not isinstance(datacenter, str):
            raise TypeError("Expected argument 'datacenter' to be a str")
        pulumi.set(__self__, "datacenter", datacenter)
        if error_on_missing_keys and not isinstance(error_on_missing_keys, bool):
            raise TypeError("Expected argument 'error_on_missing_keys' to be a bool")
        pulumi.set(__self__, "error_on_missing_keys", error_on_missing_keys)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if keys and not isinstance(keys, list):
            raise TypeError("Expected argument 'keys' to be a list")
        pulumi.set(__self__, "keys", keys)
        if namespace and not isinstance(namespace, str):
            raise TypeError("Expected argument 'namespace' to be a str")
        pulumi.set(__self__, "namespace", namespace)
        if partition and not isinstance(partition, str):
            raise TypeError("Expected argument 'partition' to be a str")
        pulumi.set(__self__, "partition", partition)
        if token and not isinstance(token, str):
            raise TypeError("Expected argument 'token' to be a str")
        pulumi.set(__self__, "token", token)
        if var and not isinstance(var, dict):
            raise TypeError("Expected argument 'var' to be a dict")
        pulumi.set(__self__, "var", var)

    @property
    @pulumi.getter
    def datacenter(self) -> str:
        """
        The datacenter to use. This overrides the agent's default datacenter and the datacenter in the provider setup.
        """
        return pulumi.get(self, "datacenter")

    @property
    @pulumi.getter(name="errorOnMissingKeys")
    def error_on_missing_keys(self) -> Optional[bool]:
        """
        Whether to return an error when a key is absent from the KV store and no default is configured. This defaults to `false`.
        """
        return pulumi.get(self, "error_on_missing_keys")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def keys(self) -> Optional[Sequence['outputs.GetKeysKeyResult']]:
        """
        Specifies a key in Consul to be read. Supported values documented below. Multiple blocks supported.
        """
        return pulumi.get(self, "keys")

    @property
    @pulumi.getter
    def namespace(self) -> Optional[str]:
        """
        The namespace to lookup the keys.
        """
        return pulumi.get(self, "namespace")

    @property
    @pulumi.getter
    def partition(self) -> Optional[str]:
        """
        The partition to lookup the keys.
        """
        return pulumi.get(self, "partition")

    @property
    @pulumi.getter
    @_utilities.deprecated("""The token argument has been deprecated and will be removed in a future release.
Please use the token argument in the provider configuration""")
    def token(self) -> Optional[str]:
        """
        The ACL token to use. This overrides the token that the agent provides by default.
        """
        return pulumi.get(self, "token")

    @property
    @pulumi.getter
    def var(self) -> Mapping[str, str]:
        """
        For each name given, the corresponding attribute has the value of the key.
        """
        return pulumi.get(self, "var")


class AwaitableGetKeysResult(GetKeysResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetKeysResult(
            datacenter=self.datacenter,
            error_on_missing_keys=self.error_on_missing_keys,
            id=self.id,
            keys=self.keys,
            namespace=self.namespace,
            partition=self.partition,
            token=self.token,
            var=self.var)


def get_keys(datacenter: Optional[str] = None,
             error_on_missing_keys: Optional[bool] = None,
             keys: Optional[Sequence[Union['GetKeysKeyArgs', 'GetKeysKeyArgsDict']]] = None,
             namespace: Optional[str] = None,
             partition: Optional[str] = None,
             token: Optional[str] = None,
             opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetKeysResult:
    """
    The `Keys` datasource reads values from the Consul key/value store. This is a powerful way to dynamically set values in templates.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_aws as aws
    import pulumi_consul as consul

    app = consul.get_keys(datacenter="nyc1",
        keys=[{
            "name": "ami",
            "path": "service/app/launch_ami",
            "default": "ami-1234",
        }])
    # Start our instance with the dynamic ami value
    app_instance = aws.index.Instance("app", ami=app.var.ami)
    ```


    :param str datacenter: The datacenter to use. This overrides the agent's default datacenter and the datacenter in the provider setup.
    :param bool error_on_missing_keys: Whether to return an error when a key is absent from the KV store and no default is configured. This defaults to `false`.
    :param Sequence[Union['GetKeysKeyArgs', 'GetKeysKeyArgsDict']] keys: Specifies a key in Consul to be read. Supported values documented below. Multiple blocks supported.
    :param str namespace: The namespace to lookup the keys.
    :param str partition: The partition to lookup the keys.
    :param str token: The ACL token to use. This overrides the token that the agent provides by default.
    """
    __args__ = dict()
    __args__['datacenter'] = datacenter
    __args__['errorOnMissingKeys'] = error_on_missing_keys
    __args__['keys'] = keys
    __args__['namespace'] = namespace
    __args__['partition'] = partition
    __args__['token'] = token
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('consul:index/getKeys:getKeys', __args__, opts=opts, typ=GetKeysResult).value

    return AwaitableGetKeysResult(
        datacenter=pulumi.get(__ret__, 'datacenter'),
        error_on_missing_keys=pulumi.get(__ret__, 'error_on_missing_keys'),
        id=pulumi.get(__ret__, 'id'),
        keys=pulumi.get(__ret__, 'keys'),
        namespace=pulumi.get(__ret__, 'namespace'),
        partition=pulumi.get(__ret__, 'partition'),
        token=pulumi.get(__ret__, 'token'),
        var=pulumi.get(__ret__, 'var'))
def get_keys_output(datacenter: Optional[pulumi.Input[Optional[str]]] = None,
                    error_on_missing_keys: Optional[pulumi.Input[Optional[bool]]] = None,
                    keys: Optional[pulumi.Input[Optional[Sequence[Union['GetKeysKeyArgs', 'GetKeysKeyArgsDict']]]]] = None,
                    namespace: Optional[pulumi.Input[Optional[str]]] = None,
                    partition: Optional[pulumi.Input[Optional[str]]] = None,
                    token: Optional[pulumi.Input[Optional[str]]] = None,
                    opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetKeysResult]:
    """
    The `Keys` datasource reads values from the Consul key/value store. This is a powerful way to dynamically set values in templates.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_aws as aws
    import pulumi_consul as consul

    app = consul.get_keys(datacenter="nyc1",
        keys=[{
            "name": "ami",
            "path": "service/app/launch_ami",
            "default": "ami-1234",
        }])
    # Start our instance with the dynamic ami value
    app_instance = aws.index.Instance("app", ami=app.var.ami)
    ```


    :param str datacenter: The datacenter to use. This overrides the agent's default datacenter and the datacenter in the provider setup.
    :param bool error_on_missing_keys: Whether to return an error when a key is absent from the KV store and no default is configured. This defaults to `false`.
    :param Sequence[Union['GetKeysKeyArgs', 'GetKeysKeyArgsDict']] keys: Specifies a key in Consul to be read. Supported values documented below. Multiple blocks supported.
    :param str namespace: The namespace to lookup the keys.
    :param str partition: The partition to lookup the keys.
    :param str token: The ACL token to use. This overrides the token that the agent provides by default.
    """
    __args__ = dict()
    __args__['datacenter'] = datacenter
    __args__['errorOnMissingKeys'] = error_on_missing_keys
    __args__['keys'] = keys
    __args__['namespace'] = namespace
    __args__['partition'] = partition
    __args__['token'] = token
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('consul:index/getKeys:getKeys', __args__, opts=opts, typ=GetKeysResult)
    return __ret__.apply(lambda __response__: GetKeysResult(
        datacenter=pulumi.get(__response__, 'datacenter'),
        error_on_missing_keys=pulumi.get(__response__, 'error_on_missing_keys'),
        id=pulumi.get(__response__, 'id'),
        keys=pulumi.get(__response__, 'keys'),
        namespace=pulumi.get(__response__, 'namespace'),
        partition=pulumi.get(__response__, 'partition'),
        token=pulumi.get(__response__, 'token'),
        var=pulumi.get(__response__, 'var')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

address: Optional[str]
"""
The HTTP(S) API address of the agent to use. Defaults to "127.0.0.1:8500".
"""

authJwt: Optional[str]
"""
Authenticates to Consul using a JWT authentication method.
"""

caFile: Optional[str]
"""
A path to a PEM-encoded certificate authority used to verify the remote agent's certificate.
"""

caPath: Optional[str]
"""
A path to a directory of PEM-encoded certificate authority files to use to check the authenticity of client and server
connections. Can also be specified with the `CONSUL_CAPATH` environment variable.
"""

caPem: Optional[str]
"""
PEM-encoded certificate authority used to verify the remote agent's certificate.
"""

certFile: Optional[str]
"""
A path to a PEM-encoded certificate provided to the remote agent; requires use of `key_file` or `key_pem`.
"""

certPem: Optional[str]
"""
PEM-encoded certificate provided to the remote agent; requires use of `key_file` or `key_pem`.
"""

datacenter: Optional[str]
"""
The datacenter to use. Defaults to that of the agent.
"""

headers: Optional[str]
"""
A configuration block, described below, that provides additional headers to be sent along with all requests to the
Consul server. This block can be specified multiple times.
"""

httpAuth: Optional[str]
"""
HTTP Basic Authentication credentials to be used when communicating with Consul, in the format of either `user` or
`user:pass`. This may also be specified using the `CONSUL_HTTP_AUTH` environment variable.
"""

insecureHttps: Optional[bool]
"""
Boolean value to disable SSL certificate verification; setting this value to true is not recommended for production use.
Only use this with scheme set to "https".
"""

keyFile: Optional[str]
"""
A path to a PEM-encoded private key, required if `cert_file` or `cert_pem` is specified.
"""

keyPem: Optional[str]
"""
PEM-encoded private key, required if `cert_file` or `cert_pem` is specified.
"""

namespace: Optional[str]

scheme: Optional[str]
"""
The URL scheme of the agent to use ("http" or "https"). Defaults to "http".
"""

token: Optional[str]
"""
The ACL token to use by default when making requests to the agent. Can also be specified with `CONSUL_HTTP_TOKEN` or
`CONSUL_TOKEN` as an environment variable.
"""




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['AclTokenRoleAttachmentArgs', 'AclTokenRoleAttachment']

@pulumi.input_type
class AclTokenRoleAttachmentArgs:
    def __init__(__self__, *,
                 role: pulumi.Input[str],
                 token_id: pulumi.Input[str]):
        """
        The set of arguments for constructing a AclTokenRoleAttachment resource.
        :param pulumi.Input[str] role: The role name.
        :param pulumi.Input[str] token_id: The id of the token.
        """
        pulumi.set(__self__, "role", role)
        pulumi.set(__self__, "token_id", token_id)

    @property
    @pulumi.getter
    def role(self) -> pulumi.Input[str]:
        """
        The role name.
        """
        return pulumi.get(self, "role")

    @role.setter
    def role(self, value: pulumi.Input[str]):
        pulumi.set(self, "role", value)

    @property
    @pulumi.getter(name="tokenId")
    def token_id(self) -> pulumi.Input[str]:
        """
        The id of the token.
        """
        return pulumi.get(self, "token_id")

    @token_id.setter
    def token_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "token_id", value)


@pulumi.input_type
class _AclTokenRoleAttachmentState:
    def __init__(__self__, *,
                 role: Optional[pulumi.Input[str]] = None,
                 token_id: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering AclTokenRoleAttachment resources.
        :param pulumi.Input[str] role: The role name.
        :param pulumi.Input[str] token_id: The id of the token.
        """
        if role is not None:
            pulumi.set(__self__, "role", role)
        if token_id is not None:
            pulumi.set(__self__, "token_id", token_id)

    @property
    @pulumi.getter
    def role(self) -> Optional[pulumi.Input[str]]:
        """
        The role name.
        """
        return pulumi.get(self, "role")

    @role.setter
    def role(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "role", value)

    @property
    @pulumi.getter(name="tokenId")
    def token_id(self) -> Optional[pulumi.Input[str]]:
        """
        The id of the token.
        """
        return pulumi.get(self, "token_id")

    @token_id.setter
    def token_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "token_id", value)


class AclTokenRoleAttachment(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 role: Optional[pulumi.Input[str]] = None,
                 token_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        ## Import

        `consul_acl_token_role_attachment` can be imported. This is especially useful to manage the
        policies attached to the anonymous and the master tokens with Terraform:

        ```sh
        $ pulumi import consul:index/aclTokenRoleAttachment:AclTokenRoleAttachment anonymous token_id:role_id
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] role: The role name.
        :param pulumi.Input[str] token_id: The id of the token.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: AclTokenRoleAttachmentArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Import

        `consul_acl_token_role_attachment` can be imported. This is especially useful to manage the
        policies attached to the anonymous and the master tokens with Terraform:

        ```sh
        $ pulumi import consul:index/aclTokenRoleAttachment:AclTokenRoleAttachment anonymous token_id:role_id
        ```

        :param str resource_name: The name of the resource.
        :param AclTokenRoleAttachmentArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AclTokenRoleAttachmentArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 role: Optional[pulumi.Input[str]] = None,
                 token_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AclTokenRoleAttachmentArgs.__new__(AclTokenRoleAttachmentArgs)

            if role is None and not opts.urn:
                raise TypeError("Missing required property 'role'")
            __props__.__dict__["role"] = role
            if token_id is None and not opts.urn:
                raise TypeError("Missing required property 'token_id'")
            __props__.__dict__["token_id"] = token_id
        super(AclTokenRoleAttachment, __self__).__init__(
            'consul:index/aclTokenRoleAttachment:AclTokenRoleAttachment',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            role: Optional[pulumi.Input[str]] = None,
            token_id: Optional[pulumi.Input[str]] = None) -> 'AclTokenRoleAttachment':
        """
        Get an existing AclTokenRoleAttachment resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] role: The role name.
        :param pulumi.Input[str] token_id: The id of the token.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AclTokenRoleAttachmentState.__new__(_AclTokenRoleAttachmentState)

        __props__.__dict__["role"] = role
        __props__.__dict__["token_id"] = token_id
        return AclTokenRoleAttachment(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def role(self) -> pulumi.Output[str]:
        """
        The role name.
        """
        return pulumi.get(self, "role")

    @property
    @pulumi.getter(name="tokenId")
    def token_id(self) -> pulumi.Output[str]:
        """
        The id of the token.
        """
        return pulumi.get(self, "token_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['NamespaceArgs', 'Namespace']

@pulumi.input_type
class NamespaceArgs:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[str]] = None,
                 meta: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 partition: Optional[pulumi.Input[str]] = None,
                 policy_defaults: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 role_defaults: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None):
        """
        The set of arguments for constructing a Namespace resource.
        :param pulumi.Input[str] description: Free form namespace description.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] meta: Specifies arbitrary KV metadata to associate with the namespace.
        :param pulumi.Input[str] name: The namespace name.
        :param pulumi.Input[str] partition: The partition to create the namespace within.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] policy_defaults: The list of default policies that should be applied to all tokens created in this namespace.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] role_defaults: The list of default roles that should be applied to all tokens created in this namespace.
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if meta is not None:
            pulumi.set(__self__, "meta", meta)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if partition is not None:
            pulumi.set(__self__, "partition", partition)
        if policy_defaults is not None:
            pulumi.set(__self__, "policy_defaults", policy_defaults)
        if role_defaults is not None:
            pulumi.set(__self__, "role_defaults", role_defaults)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Free form namespace description.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def meta(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        Specifies arbitrary KV metadata to associate with the namespace.
        """
        return pulumi.get(self, "meta")

    @meta.setter
    def meta(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "meta", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The namespace name.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def partition(self) -> Optional[pulumi.Input[str]]:
        """
        The partition to create the namespace within.
        """
        return pulumi.get(self, "partition")

    @partition.setter
    def partition(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "partition", value)

    @property
    @pulumi.getter(name="policyDefaults")
    def policy_defaults(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The list of default policies that should be applied to all tokens created in this namespace.
        """
        return pulumi.get(self, "policy_defaults")

    @policy_defaults.setter
    def policy_defaults(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "policy_defaults", value)

    @property
    @pulumi.getter(name="roleDefaults")
    def role_defaults(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The list of default roles that should be applied to all tokens created in this namespace.
        """
        return pulumi.get(self, "role_defaults")

    @role_defaults.setter
    def role_defaults(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "role_defaults", value)


@pulumi.input_type
class _NamespaceState:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[str]] = None,
                 meta: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 partition: Optional[pulumi.Input[str]] = None,
                 policy_defaults: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 role_defaults: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None):
        """
        Input properties used for looking up and filtering Namespace resources.
        :param pulumi.Input[str] description: Free form namespace description.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] meta: Specifies arbitrary KV metadata to associate with the namespace.
        :param pulumi.Input[str] name: The namespace name.
        :param pulumi.Input[str] partition: The partition to create the namespace within.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] policy_defaults: The list of default policies that should be applied to all tokens created in this namespace.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] role_defaults: The list of default roles that should be applied to all tokens created in this namespace.
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if meta is not None:
            pulumi.set(__self__, "meta", meta)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if partition is not None:
            pulumi.set(__self__, "partition", partition)
        if policy_defaults is not None:
            pulumi.set(__self__, "policy_defaults", policy_defaults)
        if role_defaults is not None:
            pulumi.set(__self__, "role_defaults", role_defaults)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Free form namespace description.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def meta(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        Specifies arbitrary KV metadata to associate with the namespace.
        """
        return pulumi.get(self, "meta")

    @meta.setter
    def meta(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "meta", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The namespace name.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def partition(self) -> Optional[pulumi.Input[str]]:
        """
        The partition to create the namespace within.
        """
        return pulumi.get(self, "partition")

    @partition.setter
    def partition(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "partition", value)

    @property
    @pulumi.getter(name="policyDefaults")
    def policy_defaults(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The list of default policies that should be applied to all tokens created in this namespace.
        """
        return pulumi.get(self, "policy_defaults")

    @policy_defaults.setter
    def policy_defaults(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "policy_defaults", value)

    @property
    @pulumi.getter(name="roleDefaults")
    def role_defaults(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The list of default roles that should be applied to all tokens created in this namespace.
        """
        return pulumi.get(self, "role_defaults")

    @role_defaults.setter
    def role_defaults(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "role_defaults", value)


class Namespace(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 meta: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 partition: Optional[pulumi.Input[str]] = None,
                 policy_defaults: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 role_defaults: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 __props__=None):
        """
        > **NOTE:** This feature requires Consul Enterprise.

        The `Namespace` resource provides isolated [Consul Enterprise Namespaces](https://www.consul.io/docs/enterprise/namespaces/index.html).

        ## Example Usage

        ```python
        import pulumi
        import pulumi_consul as consul

        production = consul.Namespace("production",
            name="production",
            description="Production namespace",
            meta={
                "foo": "bar",
            })
        ```

        ## Import

        `consul_namespace` can be imported. This is useful to manage attributes of the
        default namespace that is created automatically:

        ```sh
        $ pulumi import consul:index/namespace:Namespace default default
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] description: Free form namespace description.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] meta: Specifies arbitrary KV metadata to associate with the namespace.
        :param pulumi.Input[str] name: The namespace name.
        :param pulumi.Input[str] partition: The partition to create the namespace within.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] policy_defaults: The list of default policies that should be applied to all tokens created in this namespace.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] role_defaults: The list of default roles that should be applied to all tokens created in this namespace.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[NamespaceArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        > **NOTE:** This feature requires Consul Enterprise.

        The `Namespace` resource provides isolated [Consul Enterprise Namespaces](https://www.consul.io/docs/enterprise/namespaces/index.html).

        ## Example Usage

        ```python
        import pulumi
        import pulumi_consul as consul

        production = consul.Namespace("production",
            name="production",
            description="Production namespace",
            meta={
                "foo": "bar",
            })
        ```

        ## Import

        `consul_namespace` can be imported. This is useful to manage attributes of the
        default namespace that is created automatically:

        ```sh
        $ pulumi import consul:index/namespace:Namespace default default
        ```

        :param str resource_name: The name of the resource.
        :param NamespaceArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(NamespaceArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 meta: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 partition: Optional[pulumi.Input[str]] = None,
                 policy_defaults: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 role_defaults: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = NamespaceArgs.__new__(NamespaceArgs)

            __props__.__dict__["description"] = description
            __props__.__dict__["meta"] = meta
            __props__.__dict__["name"] = name
            __props__.__dict__["partition"] = partition
            __props__.__dict__["policy_defaults"] = policy_defaults
            __props__.__dict__["role_defaults"] = role_defaults
        super(Namespace, __self__).__init__(
            'consul:index/namespace:Namespace',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            description: Optional[pulumi.Input[str]] = None,
            meta: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
            name: Optional[pulumi.Input[str]] = None,
            partition: Optional[pulumi.Input[str]] = None,
            policy_defaults: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            role_defaults: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None) -> 'Namespace':
        """
        Get an existing Namespace resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] description: Free form namespace description.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] meta: Specifies arbitrary KV metadata to associate with the namespace.
        :param pulumi.Input[str] name: The namespace name.
        :param pulumi.Input[str] partition: The partition to create the namespace within.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] policy_defaults: The list of default policies that should be applied to all tokens created in this namespace.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] role_defaults: The list of default roles that should be applied to all tokens created in this namespace.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _NamespaceState.__new__(_NamespaceState)

        __props__.__dict__["description"] = description
        __props__.__dict__["meta"] = meta
        __props__.__dict__["name"] = name
        __props__.__dict__["partition"] = partition
        __props__.__dict__["policy_defaults"] = policy_defaults
        __props__.__dict__["role_defaults"] = role_defaults
        return Namespace(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[str]]:
        """
        Free form namespace description.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def meta(self) -> pulumi.Output[Optional[Mapping[str, str]]]:
        """
        Specifies arbitrary KV metadata to associate with the namespace.
        """
        return pulumi.get(self, "meta")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The namespace name.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def partition(self) -> pulumi.Output[Optional[str]]:
        """
        The partition to create the namespace within.
        """
        return pulumi.get(self, "partition")

    @property
    @pulumi.getter(name="policyDefaults")
    def policy_defaults(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        The list of default policies that should be applied to all tokens created in this namespace.
        """
        return pulumi.get(self, "policy_defaults")

    @property
    @pulumi.getter(name="roleDefaults")
    def role_defaults(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        The list of default roles that should be applied to all tokens created in this namespace.
        """
        return pulumi.get(self, "role_defaults")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetAclPolicyResult',
    'AwaitableGetAclPolicyResult',
    'get_acl_policy',
    'get_acl_policy_output',
]

@pulumi.output_type
class GetAclPolicyResult:
    """
    A collection of values returned by getAclPolicy.
    """
    def __init__(__self__, datacenters=None, description=None, id=None, name=None, namespace=None, partition=None, rules=None):
        if datacenters and not isinstance(datacenters, list):
            raise TypeError("Expected argument 'datacenters' to be a list")
        pulumi.set(__self__, "datacenters", datacenters)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if namespace and not isinstance(namespace, str):
            raise TypeError("Expected argument 'namespace' to be a str")
        pulumi.set(__self__, "namespace", namespace)
        if partition and not isinstance(partition, str):
            raise TypeError("Expected argument 'partition' to be a str")
        pulumi.set(__self__, "partition", partition)
        if rules and not isinstance(rules, str):
            raise TypeError("Expected argument 'rules' to be a str")
        pulumi.set(__self__, "rules", rules)

    @property
    @pulumi.getter
    def datacenters(self) -> Sequence[str]:
        """
        The datacenters associated with the ACL Policy.
        """
        return pulumi.get(self, "datacenters")

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        The description of the ACL Policy.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> str:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def namespace(self) -> Optional[str]:
        return pulumi.get(self, "namespace")

    @property
    @pulumi.getter
    def partition(self) -> Optional[str]:
        return pulumi.get(self, "partition")

    @property
    @pulumi.getter
    def rules(self) -> str:
        """
        The rules associated with the ACL Policy.
        """
        return pulumi.get(self, "rules")


class AwaitableGetAclPolicyResult(GetAclPolicyResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetAclPolicyResult(
            datacenters=self.datacenters,
            description=self.description,
            id=self.id,
            name=self.name,
            namespace=self.namespace,
            partition=self.partition,
            rules=self.rules)


def get_acl_policy(name: Optional[str] = None,
                   namespace: Optional[str] = None,
                   partition: Optional[str] = None,
                   opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetAclPolicyResult:
    """
    The `AclPolicy` data source returns the information related to a
    [Consul ACL Policy](https://www.consul.io/docs/acl/acl-system.html#acl-policies).

    ## Example Usage

    ```python
    import pulumi
    import pulumi_consul as consul

    agent = consul.get_acl_policy(name="agent")
    pulumi.export("consulAclPolicy", agent.rules)
    ```


    :param str name: The name of the ACL Policy.
    :param str namespace: The namespace to lookup the policy.
    :param str partition: The partition to lookup the policy.
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['namespace'] = namespace
    __args__['partition'] = partition
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('consul:index/getAclPolicy:getAclPolicy', __args__, opts=opts, typ=GetAclPolicyResult).value

    return AwaitableGetAclPolicyResult(
        datacenters=pulumi.get(__ret__, 'datacenters'),
        description=pulumi.get(__ret__, 'description'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        namespace=pulumi.get(__ret__, 'namespace'),
        partition=pulumi.get(__ret__, 'partition'),
        rules=pulumi.get(__ret__, 'rules'))
def get_acl_policy_output(name: Optional[pulumi.Input[str]] = None,
                          namespace: Optional[pulumi.Input[Optional[str]]] = None,
                          partition: Optional[pulumi.Input[Optional[str]]] = None,
                          opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetAclPolicyResult]:
    """
    The `AclPolicy` data source returns the information related to a
    [Consul ACL Policy](https://www.consul.io/docs/acl/acl-system.html#acl-policies).

    ## Example Usage

    ```python
    import pulumi
    import pulumi_consul as consul

    agent = consul.get_acl_policy(name="agent")
    pulumi.export("consulAclPolicy", agent.rules)
    ```


    :param str name: The name of the ACL Policy.
    :param str namespace: The namespace to lookup the policy.
    :param str partition: The partition to lookup the policy.
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['namespace'] = namespace
    __args__['partition'] = partition
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('consul:index/getAclPolicy:getAclPolicy', __args__, opts=opts, typ=GetAclPolicyResult)
    return __ret__.apply(lambda __response__: GetAclPolicyResult(
        datacenters=pulumi.get(__response__, 'datacenters'),
        description=pulumi.get(__response__, 'description'),
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name'),
        namespace=pulumi.get(__response__, 'namespace'),
        partition=pulumi.get(__response__, 'partition'),
        rules=pulumi.get(__response__, 'rules')))
